@@ -17,12 +17,12 @@ from biom3d.utils import load_config, abs_listdir, versus_one, dice
 # utils
 
 def train(config=None, log=None): 
-    cfg = import_module(config).CONFIG
+    cfg = None if not config else import_module(config).CONFIG
     builder = Builder(config=cfg,path=log)
     builder.run_training()
 
 def train_yaml(config=None, log=None): 
-    cfg = load_config(config)
+    cfg = None if not config else load_config(config)
     builder = Builder(config=cfg,path=log)
     builder.run_training()
 
@@ -213,9 +213,9 @@ if __name__=='__main__':
     parser = argparse.ArgumentParser(description="Main training file.")
     parser.add_argument("-n", "--name", type=str, default="train",
         help="Name of the tested method. Valid names: {}".format(valid_names.keys()))
-    parser.add_argument("-c", "--config", type=str, default="configs.unet_pancreas",
+    parser.add_argument("-c", "--config", type=str, default=None,
         help="Name of the python configuration file (full path and without the .py)")
-    parser.add_argument("-pc", "--pretrain_config", type=str, default="configs.vgg-dino_pancreas",
+    parser.add_argument("-pc", "--pretrain_config", type=str, default=None,
         help="Name of the python configuration file for the pretraining (full path and without the .py)")
     parser.add_argument("--config_yaml", type=str, default=None,
         help="Name of the configuration file stored in yaml format (full path and without the .py)")
